@@ -798,8 +798,6 @@ action_language_cb (GtkToggleAction *action,
 
 	html = gtkhtml_editor_get_html (editor);
 	html_engine_spell_check (html->engine);
-
-	gtkthtml_editor_emit_spell_languages_changed (editor);
 }
 
 static void
@@ -1220,14 +1218,14 @@ static GtkActionEntry core_entries[] = {
 	  GTK_STOCK_COPY,
 	  N_("_Copy"),
 	  "<Control>c",
-	  N_("Copy selected text to the clipboard"),
+	  NULL,
 	  G_CALLBACK (action_copy_cb) },
 
 	{ "cut",
 	  GTK_STOCK_CUT,
 	  N_("Cu_t"),
 	  "<Control>x",
-	  N_("Cut selected text to the clipboard"),
+	  NULL,
 	  G_CALLBACK (action_cut_cb) },
 
 	{ "find",
@@ -1276,7 +1274,7 @@ static GtkActionEntry core_entries[] = {
 	  GTK_STOCK_PASTE,
 	  N_("_Paste"),
 	  "<Control>v",
-	  N_("Paste text from the clipboard"),
+	  NULL,
 	  G_CALLBACK (action_paste_cb) },
 
 	{ "paste-quote",
@@ -1290,7 +1288,7 @@ static GtkActionEntry core_entries[] = {
 	  GTK_STOCK_REDO,
 	  N_("_Redo"),
 	  "<Shift><Control>z",
-	  N_("Redo the last undone action"),
+	  NULL,
 	  G_CALLBACK (action_redo_cb) },
 
 	{ "select-all",
@@ -1304,14 +1302,14 @@ static GtkActionEntry core_entries[] = {
 	  GTK_STOCK_FIND,
 	  N_("_Find..."),
 	  "<Control>f",
-	  N_("Search for text"),
+	  NULL,
 	  G_CALLBACK (action_show_find_cb) },
 
 	{ "show-replace",
 	  GTK_STOCK_FIND_AND_REPLACE,
 	  N_("Re_place..."),
 	  "<Control>h",
-	  N_("Search for and replace text"),
+	  NULL,
 	  G_CALLBACK (action_show_replace_cb) },
 
 	{ "spell-check",
@@ -1332,7 +1330,7 @@ static GtkActionEntry core_entries[] = {
 	  GTK_STOCK_UNDO,
 	  N_("_Undo"),
 	  "<Control>z",
-	  N_("Undo the last action"),
+	  NULL,
 	  G_CALLBACK (action_undo_cb) },
 
 	{ "unindent",
